<?php 
use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

// Incluye las librerías de PHPMailer
require 'PHPMailer/src/Exception.php';
require 'PHPMailer/src/PHPMailer.php';
require 'PHPMailer/src/SMTP.php';

// Conexión a la base de datos
include 'conexion.php';

// Validar y sanitizar datos del formulario
if (empty($_POST['nombreCompleto']) || empty($_POST['telefono']) || empty($_POST['correoElectronico']) || empty($_POST['contrasena'])) {
    die("Todos los campos son obligatorios.");
}

$nombreCompleto = filter_var($_POST['nombreCompleto'], FILTER_SANITIZE_STRING);
$telefono = filter_var($_POST['telefono'], FILTER_SANITIZE_NUMBER_INT);
$correoElectronico = filter_var($_POST['correoElectronico'], FILTER_SANITIZE_EMAIL);
$contrasena = $_POST['contrasena'];

// Validar formato del correo electrónico
if (!filter_var($correoElectronico, FILTER_VALIDATE_EMAIL)) {
    die("Correo electrónico no válido.");
}

// Validar número de teléfono
if (!preg_match('/^[0-9]{10}$/', $telefono)) {
    die("Número de teléfono no válido.");
}

// Hashear contraseña
$contrasenaHashed = password_hash($contrasena, PASSWORD_DEFAULT);

// Inicializar valores
$Correo_Verificado = 0;
$telefono_verificado = 0;

// Generar códigos de verificación
$Cod_Verificacion_Correo = str_pad(mt_rand(0, 999999), 6, '0', STR_PAD_LEFT);
$Cod_Verificacion_telefono = str_pad(mt_rand(0, 999999), 6, '0', STR_PAD_LEFT);

// Insertar datos en la base de datos utilizando consultas preparadas
$stmt = $conn->prepare("INSERT INTO usuarios (nombre_completo, telefono, correo, contrasena, Cod_Verificacion_Correo, Correo_Verificado, Cod_Verificacion_telefono, telefono_verificado) 
                        VALUES (?, ?, ?, ?, ?, ?, ?, ?)");
$stmt->bind_param("ssssiiii", $nombreCompleto, $telefono, $correoElectronico, $contrasenaHashed, $Cod_Verificacion_Correo, $Correo_Verificado, $Cod_Verificacion_telefono, $telefono_verificado);

if ($stmt->execute()) {
    // Enviar correo electrónico con PHPMailer
    $mail = new PHPMailer(true);

    try {
        // Configuración del servidor SMTP
        $mail->isSMTP();
        $mail->Host = 'mail.appunitecnica.com'; // Cambiar por tu servidor SMTP
        $mail->SMTPAuth = true;
        $mail->Username = 'cdmontoya@appunitecnica.com';  // Usuario SMTP
        $mail->Password = 'Uni2024*';                     // Contraseña SMTP
        $mail->SMTPSecure = PHPMailer::ENCRYPTION_SMTPS;  // Habilitar SSL/TLS
        $mail->Port = 465;

        // Destinatarios
        $mail->setFrom('cdmontoya@appunitecnica.com', 'Cristopher Montoya');
        $mail->addAddress($correoElectronico, $nombreCompleto); 

        // Contenido del correo
        $mail->isHTML(true);
        $mail->Subject = 'Bienvenido a la Plataforma';
        $mail->Body = '<strong>Bienvenido Navegante</strong><br><br>'
                    . 'Esta plataforma está hecha para que usted pueda llevar un inventario de su <strong>vehículo</strong>. '
                    . 'Por tal motivo requerimos que valide su correo electrónico.<br><br>'
                    . '<h2>CÓDIGO VALIDACIÓN: <strong>'.$Cod_Verificacion_Correo.'</strong></h2><br><br>'
                    . 'Dar clic en el siguiente enlace para validar: '
                    . '<a href="https://www.google.com">Validar correo</a>';

        $mail->send();
    } catch (Exception $e) {
        error_log("Error al enviar correo: " . $mail->ErrorInfo, 3, "errores.log");
        die("No se pudo enviar el mensaje. Intente nuevamente más tarde.");
    }

    // Enviar mensaje SMS con cURL
    $curl = curl_init();
    curl_setopt_array($curl, [
        CURLOPT_URL => "https://api103.hablame.co/api/sms/v3/send/marketing",
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_ENCODING => "",
        CURLOPT_MAXREDIRS => 10,
        CURLOPT_TIMEOUT => 30,
        CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
        CURLOPT_CUSTOMREQUEST => "POST",
        CURLOPT_POSTFIELDS => json_encode([
            'toNumber' => '57'.$telefono,
            'sms' => 'Hola '.$nombreCompleto.', su código de validación es: '.$Cod_Verificacion_telefono,
            'flash' => '0',
            'sc' => '890202',
            'request_dlvr_rcpt' => '0',
        ]),
        CURLOPT_HTTPHEADER => [
            "Accept: application/json",
            "Account: 10014546",
            "ApiKey: d6UeQiwJy6e6C4o6VMuhEaDi0oCzZZ",
            "Content-Type: application/json",
            "Token: b1cd03e0e3a047b69972cf2c851d117c"
        ],
    ]);

    $response = curl_exec($curl);
    $err = curl_error($curl);
    curl_close($curl);

    if ($err) {
        error_log("Error en cURL: " . $err, 3, "errores.log");
        die("Error al enviar mensaje SMS.");
    }

    // Redirigir al usuario
    header("Location: index.php?mensaje=Registro exitoso. Revise su correo y teléfono para validar su cuenta.");
    exit;
} else {
    echo "Error: " . $stmt->error;
}

// Cerrar conexión
$stmt->close();
$conn->close();
?>
